"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("../constants");
const amplify_symbol_1 = require("../../amplify-symbol");
const useAuthSignoutAction_1 = require("../useAuthSignoutAction");
jest.mock('aws-amplify');
const signOutSpy = jest.spyOn(aws_amplify_1.Auth, 'signOut');
const hubDispatchSpy = jest.spyOn(aws_amplify_1.Hub, 'dispatch');
describe('useAuthSignOutAction', () => {
    beforeEach(() => jest.clearAllMocks());
    it('should call Auth.SignOut', async () => {
        const authSignOutAction = (0, useAuthSignoutAction_1.useAuthSignOutAction)();
        await authSignOutAction();
        expect(signOutSpy).toHaveBeenCalledTimes(1);
    });
    it('should call Hub with started and finished events', async () => {
        const authSignOutAction = (0, useAuthSignoutAction_1.useAuthSignOutAction)();
        await authSignOutAction();
        expect(hubDispatchSpy).toHaveBeenCalledTimes(2);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { options: undefined },
            event: constants_1.ACTION_AUTH_SIGNOUT_STARTED,
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { options: undefined },
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    });
    it('should call Hub with started and finished events with options', async () => {
        const authSignOutAction = (0, useAuthSignoutAction_1.useAuthSignOutAction)({ global: true });
        await authSignOutAction();
        expect(hubDispatchSpy).toHaveBeenCalledTimes(2);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { options: { global: true } },
            event: constants_1.ACTION_AUTH_SIGNOUT_STARTED,
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
        expect(hubDispatchSpy).toHaveBeenCalledWith(constants_1.UI_CHANNEL, {
            data: { options: { global: true } },
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    });
});
//# sourceMappingURL=useAuthSignoutAction.test.js.map