import { PersistentModel, PersistentModelConstructor, ModelInit, PersistentModelMetaData, Schema, IdentifierFieldOrIdentifierObject, ProducerPaginationInput, RecursiveModelPredicateExtender } from '@aws-amplify/datastore';
/**
 * Converts a Model's field values to types supported by
 * Amplify UI field components. This is required
 * because Datastore Int and Float scalar types are often
 * entered by users in a TextField which returns a string
 */
declare type ModelFields<Type> = {
    [Property in keyof Type]: string | number | boolean;
};
export declare type DataStoreActionFields<Model extends PersistentModel> = ModelInit<Model, PersistentModelMetaData<Model>> | ModelFields<ModelInit<Model, PersistentModelMetaData<Model>>>;
export interface UseDataStoreActionOptions<Model extends PersistentModel> {
    model: PersistentModelConstructor<Model>;
    /**
     * Pass either already converted field values based on DataStore schema,
     * or also pass the `schema` param have string field values
     * optimistically cast to the expected type based on the `schema`
     */
    fields: DataStoreActionFields<Model>;
    /**
     * Used to optimistically cast fields values to the
     * expected value types based on the `schema` provided
     */
    schema?: Schema;
}
export declare type DataStoreItemProps<Model extends PersistentModel> = {
    model: PersistentModelConstructor<Model>;
    id: IdentifierFieldOrIdentifierObject<Model, PersistentModelMetaData<Model>>;
};
export declare type DataStoreCollectionProps<Model extends PersistentModel> = {
    model: PersistentModelConstructor<Model>;
    criteria?: RecursiveModelPredicateExtender<Model>;
    pagination?: ProducerPaginationInput<Model>;
};
declare type DataStoreBaseResult = {
    error?: Error;
    isLoading: boolean;
};
export declare type DataStoreItemResult<Model extends PersistentModel> = DataStoreBaseResult & {
    item?: Model;
};
export declare type DataStoreCollectionResult<Model extends PersistentModel> = DataStoreBaseResult & {
    items: Model[];
};
export declare type DataStoreBindingProps<Model extends PersistentModel, BindingType extends 'record' | 'collection'> = {
    type: BindingType;
} & (BindingType extends 'record' ? DataStoreItemProps<Model> : BindingType extends 'collection' ? DataStoreCollectionProps<Model> : never);
export declare type DataStorePredicateObject = {
    and?: DataStorePredicateObject[];
    or?: DataStorePredicateObject[];
    field?: string;
    operand?: string | boolean | number;
    operator?: string;
};
export {};
