"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAuthSignOutActionString = exports.useAuthSignOutAction = void 0;
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const aws_amplify_1 = require("aws-amplify");
const amplify_symbol_1 = require("../amplify-symbol");
const get_error_message_1 = require("../get-error-message");
const constants_1 = require("./constants");
const useAuthSignOutAction = (options) => async () => {
    try {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_STARTED,
            data: { options },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
        await aws_amplify_1.Auth.signOut(options);
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
            data: { options },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
    catch (error) {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_AUTH_SIGNOUT_FINISHED,
            data: { options, errorMessage: (0, get_error_message_1.getErrorMessage)(error) },
        }, constants_1.EVENT_ACTION_AUTH_SIGNOUT, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
};
exports.useAuthSignOutAction = useAuthSignOutAction;
exports.useAuthSignOutActionString = `export const useAuthSignOutAction: UseAuthSignOutAction =
  (options) => async () => {
    try {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_STARTED,
          data: { options },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );

      await Auth.signOut(options);
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_FINISHED,
          data: { options },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );
    } catch (error) {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_AUTH_SIGNOUT_FINISHED,
          data: { options, errorMessage: getErrorMessage(error) },
        },
        EVENT_ACTION_AUTH_SIGNOUT,
        AMPLIFY_SYMBOL
      );
    }
  };`;
//# sourceMappingURL=useAuthSignoutAction.js.map