"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDataStoreBindingString = exports.useDataStoreBinding = exports.useDataStoreItem = exports.useDataStoreCollection = void 0;
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
const React = __importStar(require("react"));
const datastore_1 = require("@aws-amplify/datastore");
/**
 * Perform a collection query against a DataStore model
 * @internal
 */
const useDataStoreCollection = ({ model, criteria, pagination, }) => {
    const [result, setResult] = React.useState({
        items: [],
        isLoading: false,
        error: undefined,
    });
    // eslint-disable-next-line consistent-return
    const fetch = () => {
        setResult({ isLoading: true, items: [] });
        const subscription = datastore_1.DataStore.observeQuery(model, criteria, pagination).subscribe((snapshot) => setResult({ items: snapshot.items, isLoading: false }), (error) => setResult({ items: [], error, isLoading: false }));
        if (subscription) {
            return () => subscription.unsubscribe();
        }
    };
    React.useEffect(fetch, []);
    return result;
};
exports.useDataStoreCollection = useDataStoreCollection;
/**
 * Perform a single record query against a DataStore model
 * @internal
 */
const useDataStoreItem = ({ model, id, }) => {
    const [item, setItem] = React.useState();
    const [isLoading, setLoading] = React.useState(false);
    const [error, setError] = React.useState();
    const fetch = () => {
        setLoading(true);
        datastore_1.DataStore.query(model, id)
            .then(setItem)
            .catch(setError)
            .finally(() => setLoading(false));
    };
    React.useEffect(fetch, []);
    return {
        error,
        item,
        isLoading,
    };
};
exports.useDataStoreItem = useDataStoreItem;
function useDataStoreBinding(props) {
    return props.type === 'record' ? (0, exports.useDataStoreItem)(props) : (0, exports.useDataStoreCollection)(props);
}
exports.useDataStoreBinding = useDataStoreBinding;
exports.useDataStoreBindingString = `export const useDataStoreCollection = <M extends PersistentModel>({
  model,
  criteria,
  pagination,
}: DataStoreCollectionProps<M>): DataStoreCollectionResult<M> => {
  const [result, setResult] = React.useState<DataStoreCollectionResult<M>>({
    items: [],
    isLoading: false,
    error: undefined,
  });

  const fetch = () => {
    setResult({ isLoading: true, items: [] });

    const subscription = DataStore.observeQuery(
      model,
      criteria,
      pagination
    ).subscribe(
      (snapshot) => setResult({ items: snapshot.items, isLoading: false }),
      (error: Error) => setResult({ items: [], error, isLoading: false })
    );

    if (subscription) {
      return () => subscription.unsubscribe();
    }
  };

  React.useEffect(fetch, []);
  return result;
};

export const useDataStoreItem = <M extends PersistentModel>({
  model,
  id,
}: DataStoreItemProps<M>): DataStoreItemResult<M> => {
  const [item, setItem] = React.useState<M>();
  const [isLoading, setLoading] = React.useState<boolean>(false);
  const [error, setError] = React.useState<Error>();

  const fetch = () => {
    setLoading(true);

    DataStore.query(model, id)
      .then(setItem)
      .catch(setError)
      .finally(() => setLoading(false));
  };

  React.useEffect(fetch, []);
  return {
    error,
    item,
    isLoading,
  };
};

export function useDataStoreBinding<Model extends PersistentModel>(
  props: DataStoreBindingProps<Model, 'record'>
): DataStoreItemResult<Model>;
export function useDataStoreBinding<Model extends PersistentModel>(
  props: DataStoreBindingProps<Model, 'collection'>
): DataStoreCollectionResult<Model>;
export function useDataStoreBinding<Model extends PersistentModel>(
  props:
    | DataStoreBindingProps<Model, 'record'>
    | DataStoreBindingProps<Model, 'collection'>
): DataStoreItemResult<Model> | DataStoreCollectionResult<Model> {
  return props.type === 'record'
    ? useDataStoreItem(props) : useDataStoreCollection(props);
};`;
//# sourceMappingURL=useDataStoreBinding.js.map