"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDataStoreDeleteActionString = exports.useDataStoreDeleteAction = void 0;
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("./constants");
const amplify_symbol_1 = require("../amplify-symbol");
const get_error_message_1 = require("../get-error-message");
/**
 * Action to Delete DataStore item
 * @internal
 */
const useDataStoreDeleteAction = ({ model, id }) => async () => {
    try {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_DATASTORE_DELETE_STARTED,
            data: { id },
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
        await aws_amplify_1.DataStore.delete(model, id);
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_DATASTORE_DELETE_FINISHED,
            data: { id },
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
    catch (error) {
        aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
            event: constants_1.ACTION_DATASTORE_DELETE_FINISHED,
            data: { id, errorMessage: (0, get_error_message_1.getErrorMessage)(error) },
        }, constants_1.EVENT_ACTION_DATASTORE_DELETE, amplify_symbol_1.AMPLIFY_SYMBOL);
    }
};
exports.useDataStoreDeleteAction = useDataStoreDeleteAction;
exports.useDataStoreDeleteActionString = `export const useDataStoreDeleteAction =
<Model extends PersistentModel>({
  model,
  id,
}: UseDataStoreDeleteActionOptions<Model>): (() => Promise<void>) =>
async () => {
  try {
    Hub.dispatch(
      UI_CHANNEL,
      {
        event: ACTION_DATASTORE_DELETE_STARTED,
        data: { id },
      },
      EVENT_ACTION_DATASTORE_DELETE,
      AMPLIFY_SYMBOL
    );

    await DataStore.delete(model, id);

    Hub.dispatch(
      UI_CHANNEL,
      {
        event: ACTION_DATASTORE_DELETE_FINISHED,
        data: { id },
      },
      EVENT_ACTION_DATASTORE_DELETE,
      AMPLIFY_SYMBOL
    );
  } catch (error) {
    Hub.dispatch(
      UI_CHANNEL,
      {
        event: ACTION_DATASTORE_DELETE_FINISHED,
        data: { id, errorMessage: getErrorMessage(error) },
      },
      EVENT_ACTION_DATASTORE_DELETE,
      AMPLIFY_SYMBOL
    );
  }
};`;
//# sourceMappingURL=useDataStoreDeleteAction.js.map