"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDataStoreUpdateActionString = exports.useDataStoreUpdateAction = void 0;
const aws_amplify_1 = require("aws-amplify");
const constants_1 = require("./constants");
const useTypeCastFields_1 = require("./useTypeCastFields");
const amplify_symbol_1 = require("../amplify-symbol");
const get_error_message_1 = require("../get-error-message");
/**
 * Action to Update DataStore item
 * @internal
 */
const useDataStoreUpdateAction = ({ fields: initialFields, id, model, schema, }) => {
    const fields = (0, useTypeCastFields_1.useTypeCastFields)({
        fields: initialFields,
        modelName: model.name,
        schema,
    });
    return async () => {
        try {
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_UPDATE_STARTED,
                data: { fields, id },
            }, constants_1.EVENT_ACTION_DATASTORE_UPDATE, amplify_symbol_1.AMPLIFY_SYMBOL);
            const original = await aws_amplify_1.DataStore.query(model, id);
            if (!original) {
                throw new Error(`${constants_1.DATASTORE_QUERY_BY_ID_ERROR}: ${id}`);
            }
            const item = await aws_amplify_1.DataStore.save(model.copyOf(original, (updated) => {
                Object.assign(updated, fields);
            }));
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_UPDATE_FINISHED,
                data: { fields, id, item },
            }, constants_1.EVENT_ACTION_DATASTORE_UPDATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        }
        catch (error) {
            aws_amplify_1.Hub.dispatch(constants_1.UI_CHANNEL, {
                event: constants_1.ACTION_DATASTORE_UPDATE_FINISHED,
                data: {
                    fields,
                    id,
                    errorMessage: (0, get_error_message_1.getErrorMessage)(error),
                },
            }, constants_1.EVENT_ACTION_DATASTORE_UPDATE, amplify_symbol_1.AMPLIFY_SYMBOL);
        }
    };
};
exports.useDataStoreUpdateAction = useDataStoreUpdateAction;
exports.useDataStoreUpdateActionString = `export const useDataStoreUpdateAction = <Model extends PersistentModel>({
  fields: initialFields,
  id,
  model,
  schema,
}: UseDataStoreUpdateActionOptions<Model>): (() => Promise<void>) => {
  const fields = useTypeCastFields<Model>({
    fields: initialFields,
    modelName: model.name,
    schema,
  });

  return async () => {
    try {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_UPDATE_STARTED,
          data: { fields, id },
        },
        EVENT_ACTION_DATASTORE_UPDATE,
        AMPLIFY_SYMBOL
      );

      const original = await DataStore.query(model, id);

      if (!original) {
        throw new Error(\`\${DATASTORE_QUERY_BY_ID_ERROR}: \${id}\`);
      }

      const item = await DataStore.save(
        model.copyOf(original, (updated: any) => {
          Object.assign(updated, fields);
        })
      );

      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_UPDATE_FINISHED,
          data: { fields, id, item },
        },
        EVENT_ACTION_DATASTORE_UPDATE,
        AMPLIFY_SYMBOL
      );
    } catch (error) {
      Hub.dispatch(
        UI_CHANNEL,
        {
          event: ACTION_DATASTORE_UPDATE_FINISHED,
          data: {
            fields,
            id,
            errorMessage: getErrorMessage(error),
          },
        },
        EVENT_ACTION_DATASTORE_UPDATE,
        AMPLIFY_SYMBOL
      );
    }
  };
};`;
//# sourceMappingURL=useDataStoreUpdateAction.js.map